@@ -13,21 +13,31 @@ from .entities import (
     AzureReplicationType,
     AzureStorage,
     AzureStorageTier,
+    BucketsConfig,
     CloudProvider,
     Cluster,
+    ClusterLocationType,
+    ClusterStatus,
     CredentialsConfig,
+    DisksConfig,
     DNSConfig,
     DockerRegistryConfig,
+    EFSPerformanceMode,
+    EFSThroughputMode,
     EMCECSCredentials,
     GoogleCloudProvider,
     GoogleFilestoreTier,
     GoogleStorage,
     GrafanaCredentials,
     HelmRegistryConfig,
+    IdleJobConfig,
+    IngressConfig,
     MetricsConfig,
     MinioCredentials,
     MonitoringConfig,
     NeuroAuthConfig,
+    NodePool,
+    NodeRole,
     OnPremCloudProvider,
     OpenStackCredentials,
     OrchestratorConfig,
@@ -37,6 +47,7 @@ from .entities import (
     SecretsConfig,
     SentryCredentials,
     StorageConfig,
+    StorageInstance,
     TPUPreset,
     TPUResource,
     VCDCloudProvider,
@@ -57,21 +68,31 @@ __all__ = [
     "AzureReplicationType",
     "AzureStorage",
     "AzureStorageTier",
+    "BucketsConfig",
     "CloudProvider",
     "Cluster",
+    "ClusterLocationType",
+    "ClusterStatus",
     "CredentialsConfig",
+    "DisksConfig",
     "DNSConfig",
     "DockerRegistryConfig",
+    "EFSPerformanceMode",
+    "EFSThroughputMode",
     "EMCECSCredentials",
     "GoogleCloudProvider",
     "GoogleFilestoreTier",
     "GoogleStorage",
     "GrafanaCredentials",
     "HelmRegistryConfig",
+    "IdleJobConfig",
+    "IngressConfig",
     "MetricsConfig",
     "MinioCredentials",
     "MonitoringConfig",
     "NeuroAuthConfig",
+    "NodePool",
+    "NodeRole",
     "OnPremCloudProvider",
     "OpenStackCredentials",
     "OrchestratorConfig",
@@ -81,6 +102,7 @@ __all__ = [
     "SecretsConfig",
     "SentryCredentials",
     "StorageConfig",
+    "StorageInstance",
     "TPUPreset",
     "TPUResource",
     "VCDCloudProvider",
